{% extends 'spire/authentication/page/authentication_page.html' %}

{% load crispy_forms_filters %}

{% block authentication_page_content %}
    <h5>Set Password</h5>
    <form method="POST">
        {% csrf_token %}
        {{ form.as_p }}
        <button type="submit" class="w-100 btn btn-blue mt-2">Submit</button>
    </form>
{% endblock %}
