{% load static %}
{% load django_glue %}

<!doctype html>
<html lang="en">
    <head>
        {% block base_head %}
            {% block base_head_title %}
                <title>Django Spire {% if page_title %}- {{ page_title }}{% endif %}</title>
            {% endblock %}

            {% block base_head_meta %}
                <meta charset="UTF-8">
                <meta name="viewport" content="width=device-width, initial-scale=1.0">
                <meta http-equiv="X-UA-Compatible" content="ie=edge">
            {% endblock %}

            {% block base_head_css %}

                <link rel="stylesheet" href="{% static 'spire/css/bootstrap.css' %}?v={{ DJANGO_SPIRE_VERSION }}">

                <link rel="stylesheet" href="{% static 'spire/css/app.css' %}?v={{ DJANGO_SPIRE_VERSION }}">
                <link rel="stylesheet" href="{% static 'spire/css/bootstrap-override.css' %}?v={{ DJANGO_SPIRE_VERSION }}">
                <link rel="stylesheet" href="{% static 'spire/css/bootstrap-extension.css' %}?v={{ DJANGO_SPIRE_VERSION }}">
                <link rel="stylesheet" href="{% static 'spire/css/base.css' %}?v={{ DJANGO_SPIRE_VERSION }}">

                <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css">
                <script src="https://cdn.jsdelivr.net/npm/flatpickr"></script>

                <script src="https://cdn.jsdelivr.net/npm/echarts@5.4.3/dist/echarts.min.js"></script>

                <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.1/font/bootstrap-icons.css"
                      integrity="sha384-4LISF5TTJX/fLmGSxO53rV4miRxdg84mZsxmO8Rx5jGtp/LbrixFETvWa5a6sESd"
                      crossorigin="anonymous">
            {% endblock %}

            {% block base_head_additional_css %}
            {% endblock %}

            {% block base_head_js %}
                <script type="application/javascript"
                        src="{% static 'spire/js/base.js' %}?v={{ DJANGO_SPIRE_VERSION }}"></script>
                <script type="application/javascript"
                        src="{% static 'spire/js/csrf.js' %}?v={{ DJANGO_SPIRE_VERSION }}"></script>
                <script type="application/javascript"
                        src="{% static 'spire/js/ajax.js' %}?v={{ DJANGO_SPIRE_VERSION }}"></script>
                <script type="application/javascript"
                        src="{% static 'spire/js/axios.min.js' %}?v={{ DJANGO_SPIRE_VERSION }}"></script>
                <script type="application/javascript"
                        src="{% static 'spire/js/spire_alpine.js' %}?v={{ DJANGO_SPIRE_VERSION }}"></script>
                <script type="application/javascript"
                        src="{% static 'spire/js/dispatch_modal.js' %}?v={{ DJANGO_SPIRE_VERSION }}"></script>

                <script defer src="https://cdn.jsdelivr.net/npm/@alpinejs/intersect@3.x.x/dist/cdn.min.js"></script>
                <script defer src="https://cdn.jsdelivr.net/npm/@alpinejs/mask@3.x.x/dist/cdn.min.js"></script>
                <script defer src="https://cdn.jsdelivr.net/npm/@alpinejs/collapse@3.x.x/dist/cdn.min.js"></script>
                <script defer src="https://cdn.jsdelivr.net/npm/@alpinejs/persist@3.x.x/dist/cdn.min.js"></script>
                <script defer src="https://cdn.jsdelivr.net/npm/@alpinejs/focus@3.x.x/dist/cdn.min.js"></script>
                <script defer src="https://cdn.jsdelivr.net/npm/alpinejs@3.x.x/dist/cdn.min.js"></script>
            {% endblock %}

            {% block base_head_additional_js %}
            {% endblock %}

            {% block bash_head_additional_content %}
            {% endblock %}

        {% endblock %}
    </head>

    <body class="bg-app-layer-one">
    {% block base_body %}

        {% block base_body_additional_top_js %}
        {% endblock %}

        {% block base_body_js %}
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"
                integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz"
                crossorigin="anonymous"></script>
        {% endblock %}

        {% block base_body_content %}
        {% endblock %}

        {% block base_body_additional_bottom_js %}
        {% endblock %}

        {% glue_init %}
    {% endblock %}
    </body>
</html>
