{% extends 'spire/container/container.html' %}

{% load crispy_forms_tags %}

{% block container_title %}
    {% if form_title %}
        {{ form_title }}
    {% elif page_title %}
        {{ page_title }}
    {% endif %}
{% endblock %}

{% block container_content %}
    {% include 'spire/card/form_card.html' %}
{% endblock %}
