<div class="row justify-content-between align-items-center border-bottom-secondary mb-2 pb-2">
    <div class="col-auto">
        <div class="text-uppercase text-black">
            {% block modal_content_title %}
            {% endblock %}
        </div>
    </div>

    <div class="col-auto d-flex align-items-center">
        {% block modal_content_button %}
        {% endblock %}

        <div class="mx-2">
            {% block modal_content_close_button %}
                {% include 'spire/modal/element/model_close_element.html' %}
            {% endblock %}
        </div>
    </div>
</div> 

<div class="row">
    <div class="col-12">
        {% block modal_content_content %}
        {% endblock %}
    </div>
</div>
