{% extends 'spire/page/full_page.html' %}

{% block full_page_content %}
	<div class="row justify-content-center">
        <div class="col-10">
            {% include 'spire/user_account/card/user_form_card.html' %}
        </div>
    </div>
{% endblock %}
