<a
    @click="dispatch_modal_view('{{ view_url }}'); toggle_dropdown();"
    class="border-bottom fs--1 p-0 cursor-pointer bg-app-layer-one-hover text-decoration-none text-app-secondary-dark text-app-primary-hover border-bottom"
>
    <div class="px-3 py-1 text-nowrap {{ link_css }}">
        {{ link_text }}
    </div>
</a>
