{% extends 'spire/page/page.html' %}

{% load static %}

{% block page_content %}
    <div class="rounded-3 p-3">
        <div class="row ps-3 mt-5">
            <div class="col-10 col-md-8 col-lg-6 col-xl-4 mx-auto">
                <div class="card bg-dark p-5 shadow-lg">
                    <div class="text-center mb-4">
                        <img height="50px" src="{% static '' %}" alt="">
                    </div>
                    {% block page_center_card_content %}
                    {% endblock %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}
