<li class="nav-item mb-2 ms-1">
    <a
        class="nav-link p-0 text-app-accent-hover text-white fs-0 mb-0"
        href="{{ link_url }}"
    >
        <i class="{{ link_icon }}"></i>
        <span class="px-2">{{ link_text }}</span>
    </a>
</li>
