{% extends 'spire/page/full_page.html' %}

{% block page_content %}
    <div class="row">
        <div class="col">
            {% include 'spire/home/card/home_detail_card.html' %}
        </div>
    </div>
{% endblock %}
