# Generated by Django 5.1.3 on 2024-11-08 22:57

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='MfaCode',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.CharField(editable=False, max_length=6, unique=True)),
                ('expiration_datetime', models.DateTimeField(editable=False)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='mfa_codes', related_query_name='mfa_code', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'spire_authentication_mfa_code',
            },
        ),
    ]
