{% extends 'spire/authentication/page/authentication_page.html' %}

{% load static %}
{% load crispy_forms_filters %}

{% block base_title %}Password Changed Successfully{% endblock %}

{% block authentication_page_content %}
    <h3>Password Reset</h3>
    <div class="py-2">You have successfully changed your password!</div>
    <a class="w-100 btn btn-app-primary bg-app-primary mt-2" href="{% url 'home:home' %}">Home</a>
{% endblock %}